<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr">
<context>
    <name>AboutDialog</name>
    <message>
        <source>Copyright © 2011–%1 Markus Enzenberger</source>
        <translation>Copyright © 2011–%1 Markus Enzenberger</translation>
    </message>
    <message>
        <source>Computer opponent for the board game Blokus</source>
        <translation>Un adversaire d’ordinateur pour le jeu Blokus</translation>
    </message>
    <message>
        <source>Pentobi %1</source>
        <extracomment>The argument is the application version.</extracomment>
        <translation>Pentobi %1</translation>
    </message>
</context>
<context>
    <name>AnalyzeDialog</name>
    <message>
        <source>Analysis speed:</source>
        <translation>Vitesse d’analyse :</translation>
    </message>
    <message>
        <source>Fast</source>
        <translation>Rapide</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normal</translation>
    </message>
    <message>
        <source>Slow</source>
        <translation>Lente</translation>
    </message>
</context>
<context>
    <name>AnalyzeGame</name>
    <message>
        <source>(No analysis)</source>
        <translation>(Pas d’analyse)</translation>
    </message>
</context>
<context>
    <name>AppearanceDialog</name>
    <message>
        <source>Coordinates</source>
        <translation>Coordonnées</translation>
    </message>
    <message>
        <source>Show variations</source>
        <translation>Afficher les variations</translation>
    </message>
    <message>
        <source>Light</source>
        <translation>Clair</translation>
    </message>
    <message>
        <source>Dark</source>
        <translation>Noir</translation>
    </message>
    <message>
        <source>Colorblind light</source>
        <translation>Daltonien clair</translation>
    </message>
    <message>
        <source>Colorblind dark</source>
        <translation>Daltonien noir</translation>
    </message>
    <message>
        <source>System</source>
        <extracomment>Name of theme using default system colors</extracomment>
        <translation>Système</translation>
    </message>
    <message>
        <source>Move marking:</source>
        <translation>Marquage de coups :</translation>
    </message>
    <message>
        <source>Last with dot</source>
        <translation>Dernier avec point</translation>
    </message>
    <message>
        <source>Last with number</source>
        <translation>Dernier avec numéro</translation>
    </message>
    <message>
        <source>All with number</source>
        <translation>Tous avec numéro</translation>
    </message>
    <message>
        <source>None</source>
        <extracomment>Move marking/None</extracomment>
        <translation>Aucune</translation>
    </message>
    <message>
        <source>Animations</source>
        <translation>Animations</translation>
    </message>
    <message>
        <source>Show comment:</source>
        <translation>Afficher le commentaire :</translation>
    </message>
    <message>
        <source>Always</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Toujours</translation>
    </message>
    <message>
        <source>As needed</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Comme requis</translation>
    </message>
    <message>
        <source>Never</source>
        <extracomment>Show-comment mode</extracomment>
        <translation>Jamais</translation>
    </message>
    <message>
        <source>Color theme:</source>
        <translation>Thème de couleur :</translation>
    </message>
    <message>
        <source>Move number</source>
        <extracomment>Check box in appearance dialog whether to show the move number in the status bar.</extracomment>
        <translation>Numéro de coup</translation>
    </message>
</context>
<context>
    <name>AsciiArtSaveDialog</name>
    <message>
        <source>Export ASCII Art</source>
        <translation>Exporter art ASCII</translation>
    </message>
    <message>
        <source>Text files</source>
        <translation>Fichiers texte</translation>
    </message>
</context>
<context>
    <name>BoardContextMenu</name>
    <message>
        <source>Go to Move %1</source>
        <translation>Aller au coup %1</translation>
    </message>
    <message>
        <source>Move Annotation</source>
        <translation>Annotation courante</translation>
    </message>
    <message>
        <source>Move Annotation (%1)</source>
        <extracomment>The argument is the annotation symbol for the current move</extracomment>
        <translation>Annotation courante (%1)</translation>
    </message>
</context>
<context>
    <name>ButtonApply</name>
    <message>
        <source>Apply</source>
        <translation>Appliquer</translation>
    </message>
</context>
<context>
    <name>ButtonCancel</name>
    <message>
        <source>Cancel</source>
        <translation>Annuler</translation>
    </message>
</context>
<context>
    <name>ButtonClose</name>
    <message>
        <source>Close</source>
        <translation>Fermer</translation>
    </message>
</context>
<context>
    <name>ButtonOk</name>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>ComputerDialog</name>
    <message>
        <source>Computer plays:</source>
        <translation>L’ordinateur joue :</translation>
    </message>
    <message>
        <source>Level %1</source>
        <translation>Niveau %1</translation>
    </message>
</context>
<context>
    <name>ExportImageDialog</name>
    <message>
        <source>Image width:</source>
        <translation>Largeur de l’image :</translation>
    </message>
</context>
<context>
    <name>FileDialog</name>
    <message>
        <source>Overwrite file?</source>
        <translation>Remplacer le fichier ?</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Tous les fichiers</translation>
    </message>
</context>
<context>
    <name>GameInfoDialog</name>
    <message>
        <source>Player Blue/Red:</source>
        <translation>Joueur bleu/rouge :</translation>
    </message>
    <message>
        <source>Player Purple:</source>
        <translation>Joueur violet :</translation>
    </message>
    <message>
        <source>Player Green:</source>
        <translation>Joueur vert :</translation>
    </message>
    <message>
        <source>Player Blue:</source>
        <translation>Joueur bleu :</translation>
    </message>
    <message>
        <source>Player Yellow/Green:</source>
        <translation>Joueur jaune/vert :</translation>
    </message>
    <message>
        <source>Player Orange:</source>
        <translation>Joueur orange :</translation>
    </message>
    <message>
        <source>Player Yellow:</source>
        <translation>Joueur jaune :</translation>
    </message>
    <message>
        <source>Player Red:</source>
        <translation>Joueur rouge :</translation>
    </message>
    <message>
        <source>Date:</source>
        <translation>Date :</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Temps :</translation>
    </message>
    <message>
        <source>Event:</source>
        <translation>Événement :</translation>
    </message>
    <message>
        <source>Round:</source>
        <translation>Round :</translation>
    </message>
</context>
<context>
    <name>GameModel</name>
    <message>
        <source>Purple wins with 1 point.</source>
        <translation>Violet gagne avec 1 point.</translation>
    </message>
    <message>
        <source>Purple wins with %L1 points.</source>
        <translation>Violet gagne avec %L1 points.</translation>
    </message>
    <message>
        <source>Orange wins with 1 point.</source>
        <translation>Orange gagne avec 1 point.</translation>
    </message>
    <message>
        <source>Orange wins with %L1 points.</source>
        <translation>Orange gagne avec %L1 points.</translation>
    </message>
    <message>
        <source>Game ends in a tie.</source>
        <translation>La partie se termine par une égalité.</translation>
    </message>
    <message>
        <source>Green wins with 1 point.</source>
        <translation>Vert gagne avec 1 point.</translation>
    </message>
    <message>
        <source>Green wins with %L1 points.</source>
        <translation>Vert gagne avec %L1 points.</translation>
    </message>
    <message>
        <source>Blue wins with 1 point.</source>
        <translation>Bleu gagne avec 1 point.</translation>
    </message>
    <message>
        <source>Blue wins with %L1 points.</source>
        <translation>Bleu gagne avec %L1 points.</translation>
    </message>
    <message>
        <source>Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Vert gagne (égalité résolue).</translation>
    </message>
    <message>
        <source>Blue/Red wins with 1 point.</source>
        <translation>Bleu/rouge gagne avec 1 point.</translation>
    </message>
    <message>
        <source>Blue/Red wins with %L1 points.</source>
        <translation>Bleu/rouge gagne avec %L1 points.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with 1 point.</source>
        <translation>Jaune/vert gagne avec 1 point.</translation>
    </message>
    <message>
        <source>Yellow/Green wins with %L1 points.</source>
        <translation>Jaune/vert gagne avec %L1 points.</translation>
    </message>
    <message>
        <source>Yellow/Green wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Jaune/vert gagne (égalité résolue).</translation>
    </message>
    <message>
        <source>Blue wins.</source>
        <translation>Bleu gagne.</translation>
    </message>
    <message>
        <source>Yellow wins.</source>
        <translation>Jaune gagne.</translation>
    </message>
    <message>
        <source>Red wins.</source>
        <translation>Rouge gagne.</translation>
    </message>
    <message>
        <source>Red wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Rouge gagne (égalité résolue).</translation>
    </message>
    <message>
        <source>Yellow wins (tie resolved).</source>
        <extracomment>Game variant with tie-breaker rule made later player win.</extracomment>
        <translation>Jaune gagne (égalité résolue).</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Yellow.</source>
        <translation>La partie se termine par une égalité entre bleu et jaune.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue and Red.</source>
        <translation>La partie se termine par une égalité entre bleu et rouge.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow and Red.</source>
        <translation>La partie se termine par une égalité entre jaune et rouge.</translation>
    </message>
    <message>
        <source>Game ends in a tie between all players.</source>
        <translation>La partie se termine par une égalité entre tous les joueurs.</translation>
    </message>
    <message>
        <source>Green wins.</source>
        <translation>Vert gagne.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Red.</source>
        <translation>La partie se termine par une égalité entre bleu, jaune et rouge.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Yellow and Green.</source>
        <translation>La partie se termine par une égalité entre bleu, jaune et vert.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Blue, Red and Green.</source>
        <translation>La partie se termine par une égalité entre bleu, rouge et vert.</translation>
    </message>
    <message>
        <source>Game ends in a tie between Yellow, Red and Green.</source>
        <translation>La partie se termine par une égalité entre jaune, rouge et vert.</translation>
    </message>
    <message>
        <source>Invalid Blokus SGF file. (%1)</source>
        <translation>Le fichier n’est pas un fichier Blokus SGF valable. (%1)</translation>
    </message>
    <message>
        <source>Clipboard is empty.</source>
        <translation>Le presse-papiers est vide.</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sans nom</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <extracomment>The argument is a number, which will be increased if a file with the same name already exists</extracomment>
        <translation>Sans nom %1</translation>
    </message>
    <message>
        <source>New Folder</source>
        <translation>Nouveau dossier</translation>
    </message>
    <message>
        <source>New Folder %1</source>
        <extracomment>The argument is a number, which will be increased if a folder with the same name already exists</extracomment>
        <translation>Nouveau dossier %1</translation>
    </message>
    <message>
        <source>(Setup)</source>
        <translation>(Position)</translation>
    </message>
    <message>
        <source>(No moves)</source>
        <translation>(Pas de coups)</translation>
    </message>
    <message>
        <source>Move %1</source>
        <extracomment>The argument is the current move number.</extracomment>
        <translation>Coup %1</translation>
    </message>
    <message>
        <source>Unsupported character set</source>
        <translation>Codage des caractères non supporté</translation>
    </message>
</context>
<context>
    <name>GameVariantDialog</name>
    <message>
        <source>Classic</source>
        <translation>Classique</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Duo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Junior</translation>
    </message>
    <message>
        <source>Trigon</source>
        <translation>Trigon</translation>
    </message>
    <message>
        <source>Nexos</source>
        <translation>Nexos</translation>
    </message>
    <message>
        <source>GembloQ</source>
        <translation>GembloQ</translation>
    </message>
    <message>
        <source>Callisto</source>
        <translation>Callisto</translation>
    </message>
    <message>
        <source>Players:</source>
        <translation>Joueurs :</translation>
    </message>
    <message>
        <source>Colors:</source>
        <translation>Couleurs :</translation>
    </message>
</context>
<context>
    <name>GameViewDesktop</name>
    <message>
        <source>Computer is thinking…</source>
        <translation>L’ordinateur pense…</translation>
    </message>
    <message>
        <source>Running game analysis…</source>
        <translation>Exécution de l’analyse de la partie…</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 seconds remaining)</source>
        <translation>L’ordinateur pense… (jusqu’à %1 secondes restantes)</translation>
    </message>
    <message>
        <source>Computer is thinking… (up to %1 minutes remaining)</source>
        <translation>L’ordinateur pense… (jusqu’à %1 minutes restantes)</translation>
    </message>
</context>
<context>
    <name>GotoMoveDialog</name>
    <message>
        <source>Move number:</source>
        <translation>Numéro de coup :</translation>
    </message>
</context>
<context>
    <name>HelpWindow</name>
    <message>
        <source>Pentobi Help</source>
        <translation>Aide de Pentobi</translation>
    </message>
</context>
<context>
    <name>ImageSaveDialog</name>
    <message>
        <source>Save Image</source>
        <translation>Enregistrer l’image</translation>
    </message>
    <message>
        <source>PNG image files</source>
        <translation>Image PNG</translation>
    </message>
    <message>
        <source>JPEG image files</source>
        <translation>Image JPEG</translation>
    </message>
</context>
<context>
    <name>InitialRatingDialog</name>
    <message>
        <source>Initialize your rating for this game variant.</source>
        <translation>Initialisez votre classement pour cette variante du jeu.</translation>
    </message>
    <message>
        <source>Initial rating:</source>
        <translation>Classement initial :</translation>
    </message>
    <message>
        <source>Beginner</source>
        <translation>Débutant</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Expert</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Pentobi</source>
        <extracomment>Window title if no file is loaded.</extracomment>
        <translation>Pentobi</translation>
    </message>
    <message>
        <source>Game analysis is only possible in main variation.</source>
        <translation>L’analyse de la partie n’est possible que dans la variation principale.</translation>
    </message>
    <message>
        <source>Autosaved game was changed by another instance of Pentobi. Overwrite?</source>
        <translation>Jeu sauvé automatiquement a été changé par une autre instance de Pentobi. Remplacer ?</translation>
    </message>
    <message>
        <source>Your rating has increased from %1 to %2.</source>
        <translation>Votre classement a augmenté de %1 à %2.</translation>
    </message>
    <message>
        <source>Your rating has decreased from %1 to %2.</source>
        <translation>Votre classement a diminué de %1 à %2.</translation>
    </message>
    <message>
        <source>Your rating stays at %1.</source>
        <translation>Votre classement reste à %1.</translation>
    </message>
    <message>
        <source>No permission to access storage</source>
        <translation>Aucune autorisation d’accès au stockage</translation>
    </message>
    <message>
        <source>Delete all rating information for the current game variant?</source>
        <translation>Supprimer toutes les informations de classement de l’actuelle variante du jeu ?</translation>
    </message>
    <message>
        <source>Delete all variations?</source>
        <translation>Détruire toutes les variations ?</translation>
    </message>
    <message>
        <source>Save failed.</source>
        <translation>Échec de l’enregistrement.</translation>
    </message>
    <message>
        <source>End of tree was reached. Continue search from start of the tree?</source>
        <translation>La fin de l’arbre est atteinte. Continuer la recherche depuis la racine ?</translation>
    </message>
    <message>
        <source>No comment found</source>
        <translation>Aucun commentaire trouvé</translation>
    </message>
    <message>
        <source>%1 (modified)</source>
        <extracomment>Label for modified loaded game. The argument is the file name.</extracomment>
        <translation>%1 (modifié)</translation>
    </message>
    <message>
        <source>File has been modified by another application. Reload?</source>
        <translation>Le fichier a été modifié par une autre application. Recharger ?</translation>
    </message>
    <message>
        <source>Continue computer move?</source>
        <translation>Coninuer le coup de l’ordinateur ?</translation>
    </message>
    <message>
        <source>Keep only position?</source>
        <translation>Garder seulement la position ?</translation>
    </message>
    <message>
        <source>Keep only subtree?</source>
        <translation>Garder seulement le sous-arbre ?</translation>
    </message>
    <message>
        <source>Open failed.</source>
        <translation>Échec de l’ouverture.</translation>
    </message>
    <message>
        <source>Start rated game with Purple against Pentobi level %1?</source>
        <translation>Commencer une partie classée avec violet contre Pentobi niveau %1 ?</translation>
    </message>
    <message>
        <source>Start rated game with Green against Pentobi level %1?</source>
        <translation>Commencer une partie classée avec vert contre Pentobi niveau %1 ?</translation>
    </message>
    <message>
        <source>Start rated game with Blue/Red against Pentobi level %1?</source>
        <translation>Commencer une partie classée avec bleu/rouge contre Pentobi niveau %1 ?</translation>
    </message>
    <message>
        <source>Start rated game with Blue against Pentobi level %1?</source>
        <translation>Commencer une partie classée avec bleu contre Pentobi niveau %1 ?</translation>
    </message>
    <message>
        <source>Start rated game with Orange against Pentobi level %1?</source>
        <translation>Commencer une partie classée avec orange contre Pentobi niveau %1 ?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow/Green against Pentobi level %1?</source>
        <translation>Commencer une partie classée avec jaune/vert contre Pentobi niveau %1 ?</translation>
    </message>
    <message>
        <source>Start rated game with Yellow against Pentobi level %1?</source>
        <translation>Commencer une partie classée avec jaune contre Pentobi niveau %1 ?</translation>
    </message>
    <message>
        <source>Start rated game with Red against Pentobi level %1?</source>
        <translation>Commencer une partie classée avec rouge contre Pentobi niveau %1 ?</translation>
    </message>
    <message>
        <source>You have not yet played rated games in this game variant.</source>
        <translation>Vous n’avez pas encore joué des parties classées dans cette variante du jeu.</translation>
    </message>
    <message>
        <source>Truncate this subtree?</source>
        <translation>Élaguer la branche actuelle ?</translation>
    </message>
    <message>
        <source>Truncate children?</source>
        <translation>Élaguer les branches filles ?</translation>
    </message>
    <message>
        <source>Discard game?</source>
        <translation>Abandonner la partie ?</translation>
    </message>
    <message>
        <source>Pentobi %1 (level %2)</source>
        <extracomment>Player name for game info in rated game. First argument is version of Pentobi, second argument is level.</extracomment>
        <translation>Pentobi %1 (niveau %2)</translation>
    </message>
    <message>
        <source>Human</source>
        <extracomment>Player name for game info in rated game.</extracomment>
        <translation>Personne</translation>
    </message>
    <message>
        <source>Rated game</source>
        <translation>Partie classée</translation>
    </message>
    <message>
        <source>File has been modified by another application. Overwrite?</source>
        <translation>Le fichier a été modifié par une autre application. Remplacer ?</translation>
    </message>
    <message>
        <source>%1 - Pentobi</source>
        <extracomment>Window title if file is loaded. The argument is the file name prepended with a star if the file has been modified.</extracomment>
        <translation>%1 - Pentobi</translation>
    </message>
    <message>
        <source>Not enough memory</source>
        <translation>Mémoire insuffisante</translation>
    </message>
    <message>
        <source>Game analysis aborted</source>
        <translation>Analyse de la partie abandonnée</translation>
    </message>
    <message>
        <source>Computer move aborted</source>
        <translation>Coup de l&apos;ordinateur abandonné</translation>
    </message>
    <message>
        <source>Rating information deleted</source>
        <translation>Informations de classement supprimées</translation>
    </message>
    <message>
        <source>Variations deleted</source>
        <translation>Variations supprimées</translation>
    </message>
    <message>
        <source>File saved</source>
        <translation>Fichier enregistré</translation>
    </message>
    <message>
        <source>Saving image failed or unsupported image format</source>
        <translation>Impossible d’enregistrer l’image ou format de l’image non pris en charge</translation>
    </message>
    <message>
        <source>Image saved</source>
        <translation>Image enregistrée</translation>
    </message>
    <message>
        <source>Creating image failed</source>
        <translation>La création d’image a échoué</translation>
    </message>
    <message>
        <source>Continuing rated game</source>
        <translation>Partie classée est continuée</translation>
    </message>
    <message>
        <source>Kept only position</source>
        <translation>Gardé seulement la position</translation>
    </message>
    <message>
        <source>Kept only subtree</source>
        <translation>Gardé seulement le sous-arbre</translation>
    </message>
    <message>
        <source>Variation is now %1</source>
        <translation>La variation est maintenant %1</translation>
    </message>
    <message>
        <source>Children truncated</source>
        <translation>Nœuds fils coupé</translation>
    </message>
    <message>
        <source>Setup</source>
        <extracomment>Small-screen label for setup mode (short for &quot;Setup Mode&quot;).</extracomment>
        <translation>Position</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>Rated</source>
        <extracomment>Label for ongoing rated game</extracomment>
        <translation>Classée</translation>
    </message>
    <message>
        <source>Rated %1</source>
        <extracomment>Small-screen label for finished rated game (short for &quot;Rated Game&quot;). The argument is the game number.</extracomment>
        <translation>Classée %1</translation>
    </message>
    <message>
        <source>Rated Game %1</source>
        <extracomment>Label for rated game. The argument is the game number.</extracomment>
        <translation>Partie classée %1</translation>
    </message>
    <message>
        <source>Main Variation</source>
        <translation>Variation principale</translation>
    </message>
    <message>
        <source>Beginning of Branch</source>
        <translation>Au début de la branche</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Commentaire</translation>
    </message>
    <message>
        <source>Settings</source>
        <extracomment>Menu item Computer/Settings</extracomment>
        <translation>Configuration</translation>
    </message>
    <message>
        <source>Find Move</source>
        <translation>Trouver un coup</translation>
    </message>
    <message>
        <source>Next Comment</source>
        <translation>Commentaire suivant</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Plein écran</translation>
    </message>
    <message>
        <source>Game Info</source>
        <translation>Info sur la partie</translation>
    </message>
    <message>
        <source>Move Number…</source>
        <translation>Numéro de coup…</translation>
    </message>
    <message>
        <source>Pentobi Help</source>
        <translation>Aide de Pentobi</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Nouveau</translation>
    </message>
    <message>
        <source>Rated Game</source>
        <translation>Partie classée</translation>
    </message>
    <message>
        <source>Open…</source>
        <translation>Ouvrir…</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>Jouer</translation>
    </message>
    <message>
        <source>Play Move</source>
        <extracomment>Play a single move</extracomment>
        <translation>Jouer un coup</translation>
    </message>
    <message>
        <source>Quit</source>
        <translation>Quitter</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Save As…</source>
        <translation>Enregistrer sous…</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Arrêter</translation>
    </message>
    <message>
        <source>Undo Move</source>
        <translation>Annuler le coup</translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation>Bleu/rouge</translation>
    </message>
    <message>
        <source>Purple</source>
        <translation>Violet</translation>
    </message>
    <message>
        <source>Green</source>
        <translation>Vert</translation>
    </message>
    <message>
        <source>Blue</source>
        <translation>Bleu</translation>
    </message>
    <message>
        <source>Yellow/Green</source>
        <translation>Jaune/vert</translation>
    </message>
    <message>
        <source>Orange</source>
        <translation>Orange</translation>
    </message>
    <message>
        <source>Yellow</source>
        <translation>Jaune</translation>
    </message>
    <message>
        <source>Red</source>
        <translation>Rouge</translation>
    </message>
    <message>
        <source>Pentobi failed to generate a move.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MenuComputer</name>
    <message>
        <source>Computer</source>
        <translation>Ordinateur</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu Computer. Leave empty for no shortcut.</extracomment>
        <translation>O</translation>
    </message>
    <message>
        <source>S</source>
        <extracomment>Keyboard shortcut for menu item Computer Settings. Leave empty for no shortcut.</extracomment>
        <translation>C</translation>
    </message>
    <message>
        <source>P</source>
        <extracomment>Keyboard shortcut for menu item Play. Leave empty for no shortcut.</extracomment>
        <translation>J</translation>
    </message>
    <message>
        <source>M</source>
        <extracomment>Keyboard shortcut for menu item Play Move. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>O</source>
        <extracomment>Keyboard shortcut for menu item Stop. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
</context>
<context>
    <name>MenuEdit</name>
    <message>
        <source>Edit</source>
        <translation>Édition</translation>
    </message>
    <message>
        <source>E</source>
        <extracomment>Keyboard shortcut for menu Edit. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>M</source>
        <extracomment>Keyboard shortcut for menu item Make Main Variation. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>Make Main Variation</source>
        <translation>Choisir comme variation principale</translation>
    </message>
    <message>
        <source>Variation Up</source>
        <extracomment>Short for Move Variation Up</extracomment>
        <translation>Variation vers le haut</translation>
    </message>
    <message>
        <source>U</source>
        <extracomment>Keyboard shortcut for menu item Variation Up. Leave empty for no shortcut.</extracomment>
        <translation>H</translation>
    </message>
    <message>
        <source>Variation Down</source>
        <extracomment>Short for Move Variation Down</extracomment>
        <translation>Variation vers le bas</translation>
    </message>
    <message>
        <source>W</source>
        <extracomment>Keyboard shortcut for menu item Variation Down. Leave empty for no shortcut.</extracomment>
        <translation>B</translation>
    </message>
    <message>
        <source>Delete Variations</source>
        <translation>Détruire les variations</translation>
    </message>
    <message>
        <source>D</source>
        <extracomment>Keyboard shortcut for menu item Delete Variations. Leave empty for no shortcut.</extracomment>
        <translation>D</translation>
    </message>
    <message>
        <source>Truncate</source>
        <translation>Couper</translation>
    </message>
    <message>
        <source>T</source>
        <extracomment>Keyboard shortcut for menu item Truncate. Leave empty for no shortcut.</extracomment>
        <translation>C</translation>
    </message>
    <message>
        <source>Truncate Children</source>
        <translation>Couper les branches filles</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Truncate Children. Leave empty for no shortcut.</extracomment>
        <translation>F</translation>
    </message>
    <message>
        <source>Keep Position</source>
        <translation>Garder la position</translation>
    </message>
    <message>
        <source>P</source>
        <extracomment>Keyboard shortcut for menu item Keep Position. Leave empty for no shortcut.</extracomment>
        <translation>G</translation>
    </message>
    <message>
        <source>Keep Subtree</source>
        <translation>Garder le sous-arbre</translation>
    </message>
    <message>
        <source>S</source>
        <extracomment>Keyboard shortcut for menu item Keep Subtree. Leave empty for no shortcut.</extracomment>
        <translation>S</translation>
    </message>
    <message>
        <source>Setup Mode</source>
        <translation>Position</translation>
    </message>
    <message>
        <source>O</source>
        <extracomment>Keyboard shortcut for menu item Setup Mode. Leave empty for no shortcut.</extracomment>
        <translation>O</translation>
    </message>
    <message>
        <source>Next Color</source>
        <translation>Couleur suivante</translation>
    </message>
    <message>
        <source>N</source>
        <extracomment>Keyboard shortcut for menu item Next Color. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>Annotation…</source>
        <translation>Annotation…</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item Annotation. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>Made main variation</source>
        <translation>Choisi comme variation principale</translation>
    </message>
</context>
<context>
    <name>MenuExport</name>
    <message>
        <source>Export</source>
        <translation>Exporter</translation>
    </message>
    <message>
        <source>E</source>
        <extracomment>Keyboard shortcut for menu Export. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
    <message>
        <source>M</source>
        <extracomment>Keyboard shortcut for menu item Image. Leave empty for no shortcut.</extracomment>
        <translation>I</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item ASCII Art. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>Image…</source>
        <translation>Image…</translation>
    </message>
    <message>
        <source>ASCII Art…</source>
        <translation>Art ASCII…</translation>
    </message>
</context>
<context>
    <name>MenuGame</name>
    <message>
        <source>Game</source>
        <translation>Partie</translation>
    </message>
    <message>
        <source>G</source>
        <extracomment>Keyboard shortcut for menu Game. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>N</source>
        <extracomment>Keyboard shortcut for menu item New. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>R</source>
        <extracomment>Keyboard shortcut for menu item Rated Game. Leave empty for no shortcut.</extracomment>
        <translation>C</translation>
    </message>
    <message>
        <source>Game Variant…</source>
        <translation>Variante du jeu…</translation>
    </message>
    <message>
        <source>V</source>
        <extracomment>Keyboard shortcut for menu item Game Variant. Leave empty for no shortcut.</extracomment>
        <translation>V</translation>
    </message>
    <message>
        <source>I</source>
        <extracomment>Keyboard shortcut for menu item Game Info. Leave empty for no shortcut.</extracomment>
        <translation>I</translation>
    </message>
    <message>
        <source>U</source>
        <extracomment>Keyboard shortcut for menu item Undo. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>F</source>
        <extracomment>Keyboard shortcut for menu item Find Move. Leave empty for no shortcut.</extracomment>
        <translation>T</translation>
    </message>
    <message>
        <source>O</source>
        <extracomment>Keyboard shortcut for menu item Open. Leave empty for no shortcut.</extracomment>
        <translation>O</translation>
    </message>
    <message>
        <source>Open Clipboard</source>
        <translation>Ouvrir le presse-papiers</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Open Clipboard. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>S</source>
        <extracomment>Keyboard shortcut for menu item Save. Leave empty for no shortcut.</extracomment>
        <translation>R</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item Save As. Leave empty for no shortcut.</extracomment>
        <translation>S</translation>
    </message>
    <message>
        <source>Q</source>
        <extracomment>Keyboard shortcut for menu item Quit. Leave empty for no shortcut.</extracomment>
        <translation>Q</translation>
    </message>
</context>
<context>
    <name>MenuGo</name>
    <message>
        <source>Go</source>
        <translation>Déplacement</translation>
    </message>
    <message>
        <source>O</source>
        <extracomment>Keyboard shortcut for menu Go. Leave empty for no shortcut.</extracomment>
        <translation>D</translation>
    </message>
    <message>
        <source>N</source>
        <extracomment>Keyboard shortcut for menu item Go/Move Number. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>M</source>
        <extracomment>Keyboard shortcut for menu item Go/Main Variation. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Keyboard shortcut for menu item Beginning Of Branch. Leave empty for no shortcut.</extracomment>
        <translation>D</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Next Comment. Leave empty for no shortcut.</extracomment>
        <translation>C</translation>
    </message>
</context>
<context>
    <name>MenuHelp</name>
    <message>
        <source>Help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <source>H</source>
        <extracomment>Keyboard shortcut for menu Help. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
    <message>
        <source>P</source>
        <extracomment>Keyboard shortcut for menu item Pentobi Help. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>About Pentobi</source>
        <translation>À propos de Pentobi</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item About Pentobi. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>Report Bug</source>
        <translation>Rapportez une erreur</translation>
    </message>
    <message>
        <source>B</source>
        <extracomment>Keyboard shortcut for menu item Report Bug. Leave empty for no shortcut.</extracomment>
        <translation>R</translation>
    </message>
</context>
<context>
    <name>MenuItem</name>
    <message>
        <source>Ctrl</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation>Ctrl</translation>
    </message>
    <message>
        <source>Shift</source>
        <extracomment>Shortcut modifier key as displayed in menu item text (abbreviate if long)</extracomment>
        <translation>Maj</translation>
    </message>
</context>
<context>
    <name>MenuRecentFiles</name>
    <message>
        <source>Open Recent</source>
        <translation>Fichiers récents</translation>
    </message>
    <message>
        <source>P</source>
        <extracomment>Keyboard shortcut for menu Open Recent. Leave empty for no shortcut.</extracomment>
        <translation>F</translation>
    </message>
    <message>
        <source>%1. %2</source>
        <extracomment>Format in recent files menu. First argument is the file number, second argument the file name.</extracomment>
        <translation>%1. %2</translation>
    </message>
    <message>
        <source>Clear List</source>
        <extracomment>Menu item for clearing the recent files list</extracomment>
        <translation>Effacer la liste</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Recent Files/Clear List. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
</context>
<context>
    <name>MenuTools</name>
    <message>
        <source>Tools</source>
        <translation>Outils</translation>
    </message>
    <message>
        <source>T</source>
        <extracomment>Keyboard shortcut for menu Tools. Leave empty for no shortcut.</extracomment>
        <translation>U</translation>
    </message>
    <message>
        <source>Rating</source>
        <translation>Classement</translation>
    </message>
    <message>
        <source>R</source>
        <extracomment>Keyboard shortcut for menu item Rating. Leave empty for no shortcut.</extracomment>
        <translation>C</translation>
    </message>
    <message>
        <source>Clear Rating</source>
        <translation>Effacer le classement</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item Clear Rating. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
    <message>
        <source>Analyze Game</source>
        <translation type="vanished">Analyser la partie</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu item Analyze Game. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>Clear Analysis</source>
        <translation>Effacer l’analyse</translation>
    </message>
    <message>
        <source>E</source>
        <extracomment>Keyboard shortcut for menu item Clear Analysis. Leave empty for no shortcut.</extracomment>
        <translation>N</translation>
    </message>
    <message>
        <source>Analyze Game…</source>
        <translation>Analyser la partie…</translation>
    </message>
</context>
<context>
    <name>MenuView</name>
    <message>
        <source>View</source>
        <translation>Affichage</translation>
    </message>
    <message>
        <source>V</source>
        <extracomment>Keyboard shortcut for menu View. Leave empty for no shortcut.</extracomment>
        <translation>A</translation>
    </message>
    <message>
        <source>A</source>
        <extracomment>Keyboard shortcut for menu Appearance. Leave empty for no shortcut.</extracomment>
        <translation>E</translation>
    </message>
    <message>
        <source>F</source>
        <extracomment>Keyboard shortcut for menu item Fullscreen. Leave empty for no shortcut.</extracomment>
        <translation>P</translation>
    </message>
    <message>
        <source>C</source>
        <extracomment>Keyboard shortcut for menu item View/Comment. Leave empty for no shortcut.</extracomment>
        <translation>C</translation>
    </message>
    <message>
        <source>Appearance</source>
        <translation>Apparence</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barre d’outils</translation>
    </message>
    <message>
        <source>T</source>
        <extracomment>Keyboard shortcut for menu item View/Toolbar. Leave empty for no shortcut.</extracomment>
        <translation>B</translation>
    </message>
</context>
<context>
    <name>MoveAnnotationDialog</name>
    <message>
        <source>Move %1</source>
        <translation>Coup %1</translation>
    </message>
    <message>
        <source>Very good</source>
        <translation>Très bon</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Bon</translation>
    </message>
    <message>
        <source>Interesting</source>
        <translation>Intéressant</translation>
    </message>
    <message>
        <source>Doubtful</source>
        <translation>Douteux</translation>
    </message>
    <message>
        <source>Bad</source>
        <translation>Mauvais</translation>
    </message>
    <message>
        <source>Very Bad</source>
        <translation>Très mauvais</translation>
    </message>
    <message>
        <source>No annotation</source>
        <translation>Aucune annotation</translation>
    </message>
</context>
<context>
    <name>NewFolderDialog</name>
    <message>
        <source>Folder name:</source>
        <translation>Nom de dossier :</translation>
    </message>
</context>
<context>
    <name>OpenDialog</name>
    <message>
        <source>Open</source>
        <translation>Ouvrir</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Parties de Blokus</translation>
    </message>
</context>
<context>
    <name>RatingDialog</name>
    <message>
        <source>Your rating:</source>
        <translation>Votre classement :</translation>
    </message>
    <message>
        <source>Game variant:</source>
        <translation>Variante du jeu :</translation>
    </message>
    <message>
        <source>Classic (2)</source>
        <extracomment>Short for Classic (2 players)</extracomment>
        <translation>Classique (2)</translation>
    </message>
    <message>
        <source>Classic (3)</source>
        <extracomment>Short for Classic (3 players)</extracomment>
        <translation>Classique (3)</translation>
    </message>
    <message>
        <source>Classic (4)</source>
        <extracomment>Short for Classic (4 players)</extracomment>
        <translation>Classique (4)</translation>
    </message>
    <message>
        <source>Duo</source>
        <translation>Duo</translation>
    </message>
    <message>
        <source>Junior</source>
        <translation>Junior</translation>
    </message>
    <message>
        <source>Trigon (2)</source>
        <extracomment>Short for Trigon (2 players)</extracomment>
        <translation>Trigon (2)</translation>
    </message>
    <message>
        <source>Trigon (3)</source>
        <extracomment>Short for Trigon (3 players)</extracomment>
        <translation>Trigon (3)</translation>
    </message>
    <message>
        <source>Trigon (4)</source>
        <extracomment>Short for Trigon (4 players)</extracomment>
        <translation>Trigon (4)</translation>
    </message>
    <message>
        <source>Nexos (2)</source>
        <extracomment>Short for Nexos (2 players)</extracomment>
        <translation>Nexos (2)</translation>
    </message>
    <message>
        <source>Nexos (4)</source>
        <extracomment>Short for Nexos (4 players)</extracomment>
        <translation>Nexos (4)</translation>
    </message>
    <message>
        <source>Callisto (2)</source>
        <extracomment>Short for Callisto (2 players, 2 colors)</extracomment>
        <translation>Callisto (2)</translation>
    </message>
    <message>
        <source>Callisto (2/4)</source>
        <extracomment>Short for Callisto (2 players, 4 colors)</extracomment>
        <translation>Callisto (2/4)</translation>
    </message>
    <message>
        <source>Callisto (3)</source>
        <extracomment>Short for Callisto (3 players)</extracomment>
        <translation>Callisto (3)</translation>
    </message>
    <message>
        <source>Callisto (4)</source>
        <extracomment>Short for Callisto (4 players)</extracomment>
        <translation>Callisto (4)</translation>
    </message>
    <message>
        <source>GembloQ (4)</source>
        <extracomment>Short for GembloQ (4 players)</extracomment>
        <translation>GembloQ (4)</translation>
    </message>
    <message>
        <source>GembloQ (2)</source>
        <extracomment>Short for GembloQ (2 players, 2 colors)</extracomment>
        <translation>GembloQ (2)</translation>
    </message>
    <message>
        <source>GembloQ (2/4)</source>
        <extracomment>Short for GembloQ (2 players, 4 colors)</extracomment>
        <translation>GembloQ (2/4)</translation>
    </message>
    <message>
        <source>GembloQ (3)</source>
        <extracomment>Short for GembloQ (3 players)</extracomment>
        <translation>GembloQ (3)</translation>
    </message>
    <message>
        <source>Rated games:</source>
        <translation>Parties classées :</translation>
    </message>
    <message>
        <source>Best previous rating:</source>
        <translation>Meilleur classement précédent :</translation>
    </message>
    <message>
        <source>Recent development:</source>
        <translation>Développement récent :</translation>
    </message>
    <message>
        <source>Game</source>
        <translation type="vanished">Partie</translation>
    </message>
    <message>
        <source>Result</source>
        <translation type="vanished">Résultat</translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation type="vanished">Victoire</translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation type="vanished">Perte</translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation type="vanished">Egalité</translation>
    </message>
    <message>
        <source>Level</source>
        <translation type="vanished">Niveau</translation>
    </message>
    <message>
        <source>Your Color</source>
        <translation type="vanished">Votre couleur</translation>
    </message>
    <message>
        <source>Date</source>
        <translation type="vanished">Date</translation>
    </message>
    <message>
        <source>Open Game %1</source>
        <translation type="vanished">Ouvrir la partie %1</translation>
    </message>
</context>
<context>
    <name>SaveDialog</name>
    <message>
        <source>Save</source>
        <translation>Enregistrer</translation>
    </message>
    <message>
        <source>Blokus games</source>
        <translation>Parties de Blokus</translation>
    </message>
</context>
<context>
    <name>TableModel</name>
    <message>
        <source>Game</source>
        <extracomment>Table header for game number in rating dialog</extracomment>
        <translation>Partie</translation>
    </message>
    <message>
        <source>Result</source>
        <extracomment>Table header for game result in rating dialog</extracomment>
        <translation>Résultat</translation>
    </message>
    <message>
        <source>Level</source>
        <extracomment>Table header for level in rating dialog</extracomment>
        <translation>Niveau</translation>
    </message>
    <message>
        <source>Your Color</source>
        <extracomment>Table header for player color(s) in rating dialog</extracomment>
        <translation>Votre couleur</translation>
    </message>
    <message>
        <source>Date</source>
        <extracomment>Table header for game date in rating dialog</extracomment>
        <translation>Date</translation>
    </message>
    <message>
        <source>Win</source>
        <extracomment>Result of rated game is a win</extracomment>
        <translation>Victoire</translation>
    </message>
    <message>
        <source>Loss</source>
        <extracomment>Result of rated game is a loss</extracomment>
        <translation>Perte</translation>
    </message>
    <message>
        <source>Tie</source>
        <extracomment>Result of rated game is a tie. Abbreviate long translations to ensure that all columns of rated games list are visible on mobile devices with small screens.</extracomment>
        <translation>Egalité</translation>
    </message>
</context>
<context>
    <name>ToolBar</name>
    <message>
        <source>Start a new game</source>
        <translation>Commencer une nouvelle partie</translation>
    </message>
    <message>
        <source>Start a rated game</source>
        <translation>Commencer une partie classée</translation>
    </message>
    <message>
        <source>Set the colors played by the computer</source>
        <translation>Définir les couleurs joué par l’ordinateur</translation>
    </message>
    <message>
        <source>Make the computer continue to play the current color</source>
        <translation>Faire que l’ordinateur continue à jouer la couleur actuelle</translation>
    </message>
    <message>
        <source>Make the computer play the current color</source>
        <translation>Faire que l’ordinateur joue la couleur actuelle</translation>
    </message>
    <message>
        <source>Go to beginning of game</source>
        <translation>Aller en début de partie</translation>
    </message>
    <message>
        <source>Go ten moves backward</source>
        <translation>Revenir dix coups en arrière</translation>
    </message>
    <message>
        <source>Go one move backward</source>
        <translation>Revenir un coup en arrière</translation>
    </message>
    <message>
        <source>Go one move forward</source>
        <translation>Avancer d’un coup</translation>
    </message>
    <message>
        <source>Go ten moves forward</source>
        <translation>Avancer de dix coups</translation>
    </message>
    <message>
        <source>Go to end of moves</source>
        <translation>Aller à la fin de coups</translation>
    </message>
    <message>
        <source>Go to previous variation</source>
        <translation>Aller à la variation précédente</translation>
    </message>
    <message>
        <source>Go to next variation</source>
        <translation>Aller à la variation suivante</translation>
    </message>
    <message>
        <source>Abort game analysis</source>
        <translation>Abandonner l&apos;analyse</translation>
    </message>
    <message>
        <source>Abort computer move</source>
        <translation>Abandonner le coup de l&apos;ordinateur</translation>
    </message>
    <message>
        <source>Undo move</source>
        <extracomment>Tooltip for Undo button</extracomment>
        <translation>Annuler le coup</translation>
    </message>
    <message>
        <source>Open menu</source>
        <translation>Ouvrir le menu</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>computer opponent for the board game Blokus</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set maximum level to &lt;n&gt;.</source>
        <extracomment>Description for command line option --maxlevel</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not use opening books.</source>
        <extracomment>Description for command line option --nobook</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use layout optimized for smartphones.</source>
        <extracomment>Description for command line option --mobile</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Do not delay fast computer moves.</source>
        <extracomment>Description for command line option --nodelay</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set random seed to &lt;n&gt;.</source>
        <extracomment>Description for command line option --seed</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use &lt;n&gt; threads (0=auto).</source>
        <extracomment>Description for command line option --threads</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Print logging information to standard error.</source>
        <extracomment>Description for command line option --verbose</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>file.blksgf</source>
        <extracomment>Name of command line argument.</extracomment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blokus SGF file to open (optional).</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--maxlevel must be between 1 and %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--seed must be a positive number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>--threads must be a positive number</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Too many arguments</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
